#include <stdio.h>
#include <stdlib.h>
#include <gtk/gtk.h>
#include "applets.h"
#include "unimplemented.h"



GtkWidget *Unimplemented_Build_Objects()
{
	return NULL;
}

void Unimplemented_Free_Objects()
{
}

void Unimplemented_Save()
{
}
void Unimplemented_Restore()
{

}
